====================
Explainability (XAI)
====================


.. contents:: Table of Contents
   :local:
   :depth: 1


Measuring
~~~~~~~~~

Here are some tutorials where different systems are assessed using the metrics.

- Demos
   - `Measuring XAI using Permutation Feature Importance <explainability/demos/global_permutation.ipynb>`_
   - `Measuring XAI using Surrogate Feature Importance <explainability/demos/global_surrogate.ipynb>`_
   - `Measuring XAI using SHAP Feature Importance <explainability/demos/local_shap.ipynb>`_
   - `Measuring XAI using LIME Feature Importance <explainability/demos/local_lime.ipynb>`_

- Examples
   - `Explainability in Machine Learning - Clinical Records Analysis <explainability/examples/example_clinical_records.ipynb>`_